Class: Google::Apis::CloudtraceV1::CloudTraceService
- Inherits:
-
Google::Apis::Core::BaseService
- Object
- Google::Apis::Core::BaseService
- Google::Apis::CloudtraceV1::CloudTraceService
- Defined in:
- lib/google/apis/cloudtrace_v1/service.rb
Overview
Cloud Trace API
Sends application trace data to Cloud Trace for viewing. Trace data is collected for all App Engine applications by default. Trace data from other applications can be provided using this API. This library is used to interact with the Cloud Trace API directly. If you are looking to instrument your application for Cloud Trace, we recommend using OpenTelemetry.
Constant Summary collapse
- DEFAULT_ENDPOINT_TEMPLATE =
"https://cloudtrace.$UNIVERSE_DOMAIN$/"
Instance Attribute Summary collapse
-
#key ⇒ String
API key.
-
#quota_user ⇒ String
Available to use for quota purposes for server-side applications.
Instance Method Summary collapse
-
#get_project_trace(project_id, trace_id, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::CloudtraceV1::Trace
Gets a single trace by its ID.
-
#initialize ⇒ CloudTraceService
constructor
A new instance of CloudTraceService.
-
#list_project_traces(project_id, end_time: nil, filter: nil, order_by: nil, page_size: nil, page_token: nil, start_time: nil, view: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::CloudtraceV1::ListTracesResponse
Returns a list of traces that match the specified filter conditions.
-
#patch_project_traces(project_id, traces_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::CloudtraceV1::Empty
Sends trace spans to Cloud Trace.
Constructor Details
#initialize ⇒ CloudTraceService
Returns a new instance of CloudTraceService.
51 52 53 54 55 56 |
# File 'lib/google/apis/cloudtrace_v1/service.rb', line 51 def initialize super(DEFAULT_ENDPOINT_TEMPLATE, '', client_name: 'google-apis-cloudtrace_v1', client_version: Google::Apis::CloudtraceV1::GEM_VERSION) @batch_path = 'batch' end |
Instance Attribute Details
#key ⇒ String
Returns API key. Your API key identifies your project and provides you with API access, quota, and reports. Required unless you provide an OAuth 2.0 token.
44 45 46 |
# File 'lib/google/apis/cloudtrace_v1/service.rb', line 44 def key @key end |
#quota_user ⇒ String
Returns Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.
49 50 51 |
# File 'lib/google/apis/cloudtrace_v1/service.rb', line 49 def quota_user @quota_user end |
Instance Method Details
#get_project_trace(project_id, trace_id, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::CloudtraceV1::Trace
Gets a single trace by its ID.
114 115 116 117 118 119 120 121 122 123 |
# File 'lib/google/apis/cloudtrace_v1/service.rb', line 114 def get_project_trace(project_id, trace_id, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/projects/{projectId}/traces/{traceId}', ) command.response_representation = Google::Apis::CloudtraceV1::Trace::Representation command.response_class = Google::Apis::CloudtraceV1::Trace command.params['projectId'] = project_id unless project_id.nil? command.params['traceId'] = trace_id unless trace_id.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_project_traces(project_id, end_time: nil, filter: nil, order_by: nil, page_size: nil, page_token: nil, start_time: nil, view: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::CloudtraceV1::ListTracesResponse
Returns a list of traces that match the specified filter conditions.
170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 |
# File 'lib/google/apis/cloudtrace_v1/service.rb', line 170 def list_project_traces(project_id, end_time: nil, filter: nil, order_by: nil, page_size: nil, page_token: nil, start_time: nil, view: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/projects/{projectId}/traces', ) command.response_representation = Google::Apis::CloudtraceV1::ListTracesResponse::Representation command.response_class = Google::Apis::CloudtraceV1::ListTracesResponse command.params['projectId'] = project_id unless project_id.nil? command.query['endTime'] = end_time unless end_time.nil? command.query['filter'] = filter unless filter.nil? command.query['orderBy'] = order_by unless order_by.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['startTime'] = start_time unless start_time.nil? command.query['view'] = view unless view.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#patch_project_traces(project_id, traces_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::CloudtraceV1::Empty
Sends trace spans to Cloud Trace. Spans cannot be updated. If the trace ID and span ID already exist, an additional copy of the span will be stored.
80 81 82 83 84 85 86 87 88 89 90 |
# File 'lib/google/apis/cloudtrace_v1/service.rb', line 80 def patch_project_traces(project_id, traces_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:patch, 'v1/projects/{projectId}/traces', ) command.request_representation = Google::Apis::CloudtraceV1::Traces::Representation command.request_object = traces_object command.response_representation = Google::Apis::CloudtraceV1::Empty::Representation command.response_class = Google::Apis::CloudtraceV1::Empty command.params['projectId'] = project_id unless project_id.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |