Class: Google::Apis::CloudtraceV1::TraceSpan

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/cloudtrace_v1/classes.rb,
lib/google/apis/cloudtrace_v1/representations.rb,
lib/google/apis/cloudtrace_v1/representations.rb

Overview

A span represents a single timed event within a trace. Spans can be nested and form a trace tree. Often, a trace contains a root span that describes the end- to-end latency of an operation and, optionally, one or more subspans for its suboperations. Spans do not need to be contiguous. There may be gaps between spans in a trace.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ TraceSpan

Returns a new instance of TraceSpan.



156
157
158
# File 'lib/google/apis/cloudtrace_v1/classes.rb', line 156

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#end_timeString

End time of the span in seconds and nanoseconds from the UNIX epoch. Corresponds to the JSON property endTime

Returns:

  • (String)


114
115
116
# File 'lib/google/apis/cloudtrace_v1/classes.rb', line 114

def end_time
  @end_time
end

#kindString

Distinguishes between spans generated in a particular context. For example, two spans with the same name may be distinguished using RPC_CLIENT and RPC_SERVER to identify queueing latency associated with the span. Corresponds to the JSON property kind

Returns:

  • (String)


121
122
123
# File 'lib/google/apis/cloudtrace_v1/classes.rb', line 121

def kind
  @kind
end

#labelsHash<String,String>

Collection of labels associated with the span. Label keys must be less than 128 bytes. Label values must be less than 16 KiB. Some keys might have predefined meaning, and you can also create your own. For more information, see Cloud Trace labels. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


129
130
131
# File 'lib/google/apis/cloudtrace_v1/classes.rb', line 129

def labels
  @labels
end

#nameString

Name of the span. Must be less than 128 bytes. The span name is sanitized and displayed in the Trace tool in the Google Cloud Platform Console. The name may be a method name or some other per-call site name. For the same executable and the same call point, a best practice is to use a consistent name, which makes it easier to correlate cross-trace spans. Corresponds to the JSON property name

Returns:

  • (String)


138
139
140
# File 'lib/google/apis/cloudtrace_v1/classes.rb', line 138

def name
  @name
end

#parent_span_idFixnum

Optional. ID of the parent span, if any. Corresponds to the JSON property parentSpanId

Returns:

  • (Fixnum)


143
144
145
# File 'lib/google/apis/cloudtrace_v1/classes.rb', line 143

def parent_span_id
  @parent_span_id
end

#span_idFixnum

Identifier for the span. Must be a 64-bit integer other than 0 and unique within a trace. For example, 2205310701640571284. Corresponds to the JSON property spanId

Returns:

  • (Fixnum)


149
150
151
# File 'lib/google/apis/cloudtrace_v1/classes.rb', line 149

def span_id
  @span_id
end

#start_timeString

Start time of the span in seconds and nanoseconds from the UNIX epoch. Corresponds to the JSON property startTime

Returns:

  • (String)


154
155
156
# File 'lib/google/apis/cloudtrace_v1/classes.rb', line 154

def start_time
  @start_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



161
162
163
164
165
166
167
168
169
# File 'lib/google/apis/cloudtrace_v1/classes.rb', line 161

def update!(**args)
  @end_time = args[:end_time] if args.key?(:end_time)
  @kind = args[:kind] if args.key?(:kind)
  @labels = args[:labels] if args.key?(:labels)
  @name = args[:name] if args.key?(:name)
  @parent_span_id = args[:parent_span_id] if args.key?(:parent_span_id)
  @span_id = args[:span_id] if args.key?(:span_id)
  @start_time = args[:start_time] if args.key?(:start_time)
end